from django.utils.translation import ugettext as _

DIRECTIONALITY_CHOICES = (
    ('Inbound', _('Inbound')),
    ('Outbound', _('Outbound')),
)

API_KEY = 'prtl6749387986743898559646983194'
CURRENCY = 'EUR'
MARKET = 'ES'
LOCALE = 'en-GB'