# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-08 12:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('skyscannerSDK', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pricingoption',
            name='deeplink',
            field=models.URLField(max_length=2000),
        ),
    ]
